@@ -8,15 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.cloud_assembly_schema._jsii
-import aws_cdk.core._jsii
-import aws_cdk.cx_api._jsii
+import aws_cdk._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-bootstrapless-synthesizer",
-    "0.9.4",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-bootstrapless-synthesizer@0.9.4.jsii.tgz",
+    "cdk-bootstrapless-synthesizer@2.0.0.jsii.tgz",
 )
 
 __all__ = [
